@@ -32,13 +32,12 @@ class LinksPlugin(Plugin):
                 items.append({"name": "Report", "path": github.report_url})
             if github.fork_url:
                 items.append({"name": "Fork", "path": github.fork_url})
-            if github.edit_url:
-                items.append({"name": "Edit", "path": github.edit_url})
         return items
 
     # Process
 
     def process_markup(self, markup):
-        if self.items:
-            markup.add_style("style.css")
-            markup.add_markup("markup.html", target="#livemark-right")
+        if self.document.path == "index":
+            if self.items:
+                markup.add_style("style.css")
+                markup.add_markup("markup.html", target="#livemark-right")
